# ListAuthAuditsResponse

The results of the audit query.
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**auth_audits** | [**list[AuthAudits]**](AuthAudits.md) | List of audit records | [optional] 
**limit** | **int** | Limit on number of rows in the response | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


